<!--
  ~ Copyright (c) 2015 IBM Corporation and others.
  ~
  ~ Licensed under the Apache License, Version 2.0 (the "License");
  ~ You may not use this file except in compliance with the License.
  ~ You may obtain a copy of the License at
  ~
  ~     http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~ Unless required by applicable law or agreed to in writing, software
  ~ distributed under the License is distributed on an "AS IS" BASIS,
  ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  ~ See the License for the specific language governing permissions and
  ~ limitations under the License.
  -->


<link rel="stylesheet" type="text/css" href="{{jsloc}}/brunel.{{version}}.css">
<link rel="stylesheet" type="text/css" href="{{jsloc}}/sumoselect.css">

<style>
    {{d3css}}
</style>

<div id="{{controlsid}}" class="brunel"/>
<svg id="{{visId}}" width="{{width}}" height="{{height}}"></svg>
