/*
 * Copyright (c) 2015 IBM Corporation and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

require.config({
    waitSeconds: 60,
    paths: {
        'd3': '{{d3loc}}',
        'topojson': '{{topojsonloc}}',
        'brunel' : '{{jsloc}}/brunel.{{version}}.min',
        'brunelControls' : '{{jsloc}}/brunel.controls.{{version}}.min'
    },
    shim: {
       'brunel' : {
            exports: 'BrunelD3',
            deps: ['d3', 'topojson'],
            init: function() {
               return {
                 BrunelD3 : BrunelD3,
                 BrunelData : BrunelData
              }
            }
        },
       'brunelControls' : {
            exports: 'BrunelEventHandlers',
            init: function() {
               return {
                 BrunelEventHandlers: BrunelEventHandlers,
                 BrunelJQueryControlFactory: BrunelJQueryControlFactory
              }
            }
        }

    }

});

require(["d3"], function(d3) {
    require(["brunel", "brunelControls"], function(brunel, brunelControls) {
        {{d3js}}
    });
});
